@@ -9,16 +9,16 @@
  * List Group members
  */
 
-chdir('..');
-require_once('../src/validate.php');
-require_once('../functions/date.php');
-require_once('../functions/smtp.php');
-require_once('../functions/display_messages.php');
-require_once('../functions/addressbook.php');
-require_once('../functions/plugin.php');
-include_once('../functions/strings.php');
-include_once('../plugins/abook_group/abook_group_database.php');
-include_once('../plugins/abook_group/abook_group_functions.php');
+define('SM_PATH','../../');
+
+include_once(SM_PATH . 'include/validate.php');
+include_once(SM_PATH . 'functions/date.php');
+include_once(SM_PATH . 'functions/display_messages.php');
+include_once(SM_PATH . 'functions/addressbook.php');
+include_once(SM_PATH . 'functions/plugin.php');
+include_once(SM_PATH . 'functions/strings.php');
+include_once(SM_PATH . 'plugins/abook_group/abook_group_database.php');
+include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
 /* --- End functions --- */
 
